; ##############################################################################
; ##############################################################################
; ##############################################################################
;																				
; Timer 0+1+2 berlauf-Int aktivieren (Timer/Counter Interrupt Mask)			
;																				
TIMER_AKTIVIEREN:
	ldi temp,(0<<OCIE2)|(0<<TOIE2)|(0<<TICIE1)|(0<<OCIE1A)|(0<<OCIE1B)|(0<<TOIE1)|(1<<TOIE0)
	out TIMSK,temp       
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; TIMER0 (8Bit) Vorteiler														
;																				
; CS02 CS01 CS00 	Description													
;	0 	0 	0 		No clock source (Timer/Counter stopped).					
;	0 	0 	1 		clkI/O/		(No prescaling)									
;	0 	1 	0 		clkI/O/8 	(From prescaler)								
; *	0 	1 	1 		clkI/O/64 	(From prescaler)								
; 	1 	0 	0 		clkI/O/256 	(From prescaler)								
; 	1 	0 	1 		clkI/O/1024 (From prescaler)								
;	1 	1 	0 		External clock source on T0 pin. Clock on falling edge.		
;	1 	1 	1 		External clock source on T0 pin. Clock on rising edge.		
TIMER0_INITIALISIERUNG_1ms:
.equ TIMERWERT0	=256-125		; 50;(2 hoch 8  minus...)	
	ldi temp,(0<<CS02)|(1<<CS01)|(0<<CS00)
	OUT TCCR0,temp

	ldi temp, TIMERWERT0	; TIMER0 Startwert		
	mov TIMER0,temp
	out TCNT0,TIMER0
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
TIM0_OVF:
	GELB2_ON
	push TEMP		    ; Sichern von "TEMP" im Stack			
	in	 TEMP,SREG		; Einlesen des SREG 					
	push TEMP	    	; Schreiben von  SREG  im Stack (KOPIE)	
	out TCNT0,TIMER0
;-------------------------------------------------------------------------------
	rcall UHR
; TASTEN																		
	; Taste "M"gedrckt ? (Reset)	
	clr temp
	sbis (TASTE_M_PIN),(TASTE_M_PIN_NR)	; springe, wenn BIT(PIN) high	
	SBR temp,1
	; Taste "C"gedrckt ? (Reset)	
	sbis (TASTE_C_PIN),(TASTE_C_PIN_NR)	; springe, wenn BIT(PIN) high	
	SBR temp,2
	cpi temp,3 	
	breq TIM0_TASTEN_RESET

	; eine Taste gedrckt ?		
	LDS temp,(adr_TASTE)
	tst temp
	brne TIM0_TASTEN_FERTIG
	; Taste "M"gedrckt ?		
	clr temp
	sbis (TASTE_M_PIN),(TASTE_M_PIN_NR)	; springe, wenn BIT(PIN) high	
	SBR temp,1
	; Taste "C"gedrckt ?		
	sbis (TASTE_C_PIN),(TASTE_C_PIN_NR)	; springe, wenn BIT(PIN) high	
	SBR temp,2

	tst temp
	breq TIM0_TASTEN_FERTIG
	STS(adr_TASTE),temp		; save	
	BEEP_ON
	rjmp TIM0_TASTEN_FERTIG
;-------------------------------------------------------------------------------
TIM0_TASTEN_RESET:
	rcall EEPROM_SAVE
TIM0_TASTEN_RESET_s:
	BEEP_ON
	GRUEN_ON
	GELB_ON
	ROT_ON
	GRUEN2_ON
	GELB2_ON
	rjmp TIM0_TASTEN_RESET_s
;-------------------------------------------------------------------------------
TIM0_TASTEN_FERTIG:
;-------------------------------------------------------------------------------
; LED-DISPLAY																	
	rcall DISPLAY
;-------------------------------------------------------------------------------
TIM0_FERTIG:
	pop	TEMP			; LESEN von SREG vom STACK (KOPIE)		
	out	SREG,TEMP		; Wiederherstellen von SREG				
	pop	TEMP			; Wiederherstellen von "TEMP" 			
	GELB2_OFF
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
UHR:
	LDS temp,(adr_VT1)	; Vorteiler	
	inc temp
	cpi temp,100
	brsh UHR_VT2
	STS(adr_VT1),temp
	ret
;-------------------------------------------------------------------------------
UHR_VT2:
	STS(adr_VT1),NULL

	LDS temp,(adr_VT2)	; Vorteiler	
	inc temp
	cpi temp,10
	brsh UHR_ss
	STS(adr_VT2),temp
	ret
;-------------------------------------------------------------------------------
UHR_ss:
	STS(adr_VT2),NULL
	STS(adr_FREIGABE_ss),EINS

	LDS temp,(adr_ss)
	inc temp
	STS(adr_ss),temp
	cpi temp,60
	brsh UHR_mm
	ret
;-------------------------------------------------------------------------------
UHR_mm:
	STS(adr_ss),NULL

	LDS temp,(adr_mm)
	inc temp
	STS(adr_mm),temp
	cpi temp,60
	brsh UHR_hh
	ret
;-------------------------------------------------------------------------------
UHR_hh:
	STS(adr_mm),NULL

	push ZL
	push ZH
	LDS	ZL,(adr_hh_L)
	LDS	ZH,(adr_hh_H)
	adiw ZL,1
	STS(adr_hh_L),ZL
	STS(adr_hh_H),ZH
	pop ZH
	pop ZL
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################

